@@ -33,31 +33,31 @@ class AnalysisDataset(Dataset):
         return len(self.filepaths) - 1
 
     def __getitem__(self, item):
-        if self.coarsen <= 1: # Don't coarsen, so don't even call it
-            start = (
-                xr.open_zarr(self.filepaths[item], consolidated=True)
-            )
-            end = (
-                xr.open_zarr(self.filepaths[item + 1], consolidated=True)
-            )
+        if self.coarsen <= 1:  # Don't coarsen, so don't even call it
+            start = xr.open_zarr(self.filepaths[item], consolidated=True)
+            end = xr.open_zarr(self.filepaths[item + 1], consolidated=True)
         else:
             start = (
                 xr.open_zarr(self.filepaths[item], consolidated=True)
-                    .coarsen(latitude=self.coarsen, boundary="pad")
-                    .mean()
-                    .coarsen(longitude=self.coarsen)
-                    .mean()
+                .coarsen(latitude=self.coarsen, boundary="pad")
+                .mean()
+                .coarsen(longitude=self.coarsen)
+                .mean()
             )
             end = (
                 xr.open_zarr(self.filepaths[item + 1], consolidated=True)
-                    .coarsen(latitude=self.coarsen, boundary="pad")
-                    .mean()
-                    .coarsen(longitude=self.coarsen)
-                    .mean()
+                .coarsen(latitude=self.coarsen, boundary="pad")
+                .mean()
+                .coarsen(longitude=self.coarsen)
+                .mean()
             )
 
         # Land-sea mask data, resampled to the same as the physical variables
-        landsea = xr.open_zarr(self.invariant_path, consolidated=True).interp(latitude=start.latitude.values).interp(longitude=start.longitude.values)
+        landsea = (
+            xr.open_zarr(self.invariant_path, consolidated=True)
+            .interp(latitude=start.latitude.values)
+            .interp(longitude=start.longitude.values)
+        )
         # Calculate sin,cos, day of year, solar irradiance here before stacking
         landsea = np.stack(
             [
@@ -67,8 +67,10 @@ class AnalysisDataset(Dataset):
             ],
             axis=-1,
         )
-        landsea = landsea.T.reshape((-1,landsea.shape[-1]))
-        lat_lons = np.array(np.meshgrid(start.latitude.values, start.longitude.values)).T.reshape((-1,2))
+        landsea = landsea.T.reshape((-1, landsea.shape[-1]))
+        lat_lons = np.array(np.meshgrid(start.latitude.values, start.longitude.values)).T.reshape(
+            (-1, 2)
+        )
         sin_lat_lons = np.sin(lat_lons)
         cos_lat_lons = np.cos(lat_lons)
         date = start.time.dt.values
@@ -76,15 +78,25 @@ class AnalysisDataset(Dataset):
         sin_of_year = np.sin(day_of_year)
         cos_of_year = np.cos(day_of_year)
         solar_times = [np.array([extraterrestrial_irrad(date, lat, lon) for lat, lon in lat_lons])]
-        for when in pd.date_range(date-pd.Timedelta("12 hours"), date+pd.Timedelta("12 hours"), freq=f"1H"):
-            solar_times.append(np.array([extraterrestrial_irrad(when, lat, lon) for lat, lon in lat_lons]))
+        for when in pd.date_range(
+            date - pd.Timedelta("12 hours"), date + pd.Timedelta("12 hours"), freq=f"1H"
+        ):
+            solar_times.append(
+                np.array([extraterrestrial_irrad(when, lat, lon) for lat, lon in lat_lons])
+            )
         solar_times = np.array(solar_times)
 
         # End time solar radiation too
         end_date = end.time.dt.values
-        end_solar_times = [np.array([extraterrestrial_irrad(date, lat, lon) for lat, lon in lat_lons])]
-        for when in pd.date_range(end_date-pd.Timedelta("12 hours"), end_date+pd.Timedelta("12 hours"), freq=f"1H"):
-            end_solar_times.append(np.array([extraterrestrial_irrad(when, lat, lon) for lat, lon in lat_lons]))
+        end_solar_times = [
+            np.array([extraterrestrial_irrad(end_date, lat, lon) for lat, lon in lat_lons])
+        ]
+        for when in pd.date_range(
+            end_date - pd.Timedelta("12 hours"), end_date + pd.Timedelta("12 hours"), freq=f"1H"
+        ):
+            end_solar_times.append(
+                np.array([extraterrestrial_irrad(when, lat, lon) for lat, lon in lat_lons])
+            )
         end_solar_times = np.array(solar_times)
 
         # Normalize to between -1 and 1
@@ -103,7 +115,16 @@ class AnalysisDataset(Dataset):
             axis=-1,
         )
         # TODO Combine with above? And include sin/cos of day of year
-        input_data = np.concatenate([input_data.T.reshape((-1,input_data.shape[-1])), sin_lat_lons, cos_lat_lons, solar_times, landsea], axis=-1)
+        input_data = np.concatenate(
+            [
+                input_data.T.reshape((-1, input_data.shape[-1])),
+                sin_lat_lons,
+                cos_lat_lons,
+                solar_times,
+                landsea,
+            ],
+            axis=-1,
+        )
         # Not want to predict non-physics variables -> Output only the data variables? Would be simpler, and just add in the new ones each time
 
         output_data = np.stack(
@@ -115,12 +136,22 @@ class AnalysisDataset(Dataset):
             axis=-1,
         )
 
-        output_data = np.concatenate([output_data.T.reshape((-1,output_data.shape[-1])), sin_lat_lons, cos_lat_lons, end_solar_times, landsea], axis=-1)
+        output_data = np.concatenate(
+            [
+                output_data.T.reshape((-1, output_data.shape[-1])),
+                sin_lat_lons,
+                cos_lat_lons,
+                end_solar_times,
+                landsea,
+            ],
+            axis=-1,
+        )
         # Stick with Numpy, don't tensor it, as just going from 0 to 1
 
         # Normalize now
         return input_data, output_data
 
+
 obs_data = xr.open_zarr(
     "/home/jacob/Development/prepbufr.gdas.20160101.t00z.nr.48h.raw.zarr", consolidated=True
 )
